@@ -67,7 +67,7 @@ if repository.enumerate_versions("GtkSpell"):
 elif repository.enumerate_versions("Gtkspell"):
     try:
         import gi
-        gi.require_version('GtkSpell', '3.0')
+        gi.require_version('Gtkspell', '3.0')
         from gi.repository import Gtkspell
         HAVE_GTKSPELL = True
     except:
@@ -75,7 +75,7 @@ elif repository.enumerate_versions("Gtkspell"):
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS classes
+# Gramps classes
 #
 #-------------------------------------------------------------------------
 from gramps.gen.config import config
@@ -86,17 +86,17 @@ from gramps.gen.config import config
 #
 #-------------------------------------------------------------------------
 
-class Spell(object):
+class Spell:
     """Attach a gtkspell instance to the passed TextView instance.
     """
     _spellcheck_options = {'off': _('Off')}
-    
+
     if HAVE_GTKSPELL:
         _spellcheck_options['on'] = _('On')
-    
+
     def __init__(self, textview):
         self.textview = textview
-        
+
         if HAVE_GTKSPELL and config.get('behavior.spellcheck'):
             self.spellcheck = 'on'
         else:
@@ -106,7 +106,7 @@ class Spell(object):
         self.__real_set_active_spellcheck(self.spellcheck)
 
     # Private
-    
+
     def __real_set_active_spellcheck(self, spellcheck_code):
         """Set active spellcheck by its code."""
         if self._active_spellcheck == 'off':
@@ -146,9 +146,12 @@ class Spell(object):
                     # the language does not exist
                     # and presumably if there is no dictionary
                     if not self.gtkspell_spell.get_language_list():
-                        LOG.warn(_("You have no installed dictionaries. Either install one or disable spell checking"))
+                        LOG.warning(_("You have no installed dictionaries. "
+                                      "Either install one or disable spell "
+                                      "checking"))
                     else:
-                        LOG.warn(_("Spelling checker initialization failed: %s"), err)
+                        LOG.warning(_("Spelling checker initialization "
+                                      "failed: %s"), err)
         else:
             if spellcheck_code == 'on':
                 return
@@ -161,7 +164,7 @@ class Spell(object):
                     self._active_spellcheck = spellcheck_code
 
     # Public API
-    
+
     def get_all_spellchecks(self):
         """Get the list of installed spellcheck names."""
         return list(self._spellcheck_options.values())
@@ -172,7 +175,7 @@ class Spell(object):
             if name == spellcheck:
                 self.__real_set_active_spellcheck(code)
                 return
-        
+
     def get_active_spellcheck(self):
         """Get the name of the active spellcheck."""
         return self._spellcheck_options[self._active_spellcheck]
